@@ -106,17 +106,14 @@ def init_orchestrator(config_path: Optional[str] = None) -> Orchestrator:
             "auto_checkpoint_interval": _config.system.checkpoint_interval,
             "max_snapshots": _config.system.max_checkpoints
         },
-        "message_bus": {
-            "redis_url": _config.redis.url if _config.redis.enabled else None
+        "message_bus": {} if not _config.redis.enabled else {
+            "redis_url": _config.redis.url
         },
         "agent_manager": {
             "max_agents": _config.system.max_agents,
-            "agent_timeout": _config.system.agent_timeout
+            "heartbeat_timeout": _config.system.agent_timeout
         },
-        "resource_allocator": {
-            "default_cpu_limit": _config.resources.default_cpu_limit,
-            "default_memory_limit": _config.resources.default_memory_limit
-        }
+        "resource_allocator": {}
     }
     
     _orchestrator = Orchestrator(component_config=orchestrator_config)
