@@ -388,6 +388,10 @@ class AgentManager:
             )
             
             return agent
+        
+        except Exception as e:
+            self.logger.log_error(e, {'operation': 'spawn_agent', 'agent_type': agent_type})
+            raise AgentError(f"Failed to spawn agent: {str(e)}")
     
     async def execute_task_with_claude_agent(
         self,
@@ -474,16 +478,6 @@ class AgentManager:
             self.get_claude_agent_status(agent_id)
             for agent_id in self._claude_agents.keys()
         ]
-            
-        except Exception as e:
-            self.logger.log_error(e, {
-                'operation': 'spawn_agent',
-                'agent_type': agent_type
-            })
-            raise AgentError(
-                f"Failed to spawn agent: {str(e)}",
-                error_code="AGENT_SPAWN_FAILED"
-            )
     
     async def _initialize_agent(self, agent: Agent) -> None:
         """Initialize an agent and prepare it for work."""
