@@ -19,8 +19,15 @@ from ..interfaces.orchestrator_interface import OrchestratorInterface
 from ..interfaces.state_manager import StateManager
 from ..interfaces.message_bus import MessageBus, EventHandler
 from ..interfaces.persistence import PersistenceInterface, FilePersistence
-from ..interfaces.redis_persistence import RedisPersistence
-from ..interfaces.redis_message_bus import RedisMessageBus
+# Optional Redis imports
+try:
+    from ..interfaces.redis_persistence import RedisPersistence
+    from ..interfaces.redis_message_bus import RedisMessageBus
+    REDIS_AVAILABLE = True
+except ImportError:
+    REDIS_AVAILABLE = False
+    RedisPersistence = None
+    RedisMessageBus = None
 
 from ..core.task_planner import TaskPlanner, ExecutionPlan
 from ..core.agent_manager import AgentManager
@@ -211,7 +218,7 @@ class Orchestrator(OrchestratorInterface):
         
         # Initialize persistence backend
         if persistence_backend is None:
-            if self.use_redis:
+            if self.use_redis and REDIS_AVAILABLE:
                 # Use Redis persistence
                 redis_config = self.component_config.get('redis', {})
                 persistence_backend = RedisPersistence(
@@ -223,6 +230,8 @@ class Orchestrator(OrchestratorInterface):
                 self.logger.logger.info("Using Redis persistence backend")
             else:
                 # Use file persistence
+                if self.use_redis and not REDIS_AVAILABLE:
+                    self.logger.logger.warning("Redis requested but not available. Using file persistence instead.")
                 storage_dir = self.component_config.get('storage_directory', './maos_storage')
                 persistence_backend = FilePersistence(storage_directory=storage_dir)
                 self.logger.logger.info("Using file persistence backend")
@@ -234,7 +243,7 @@ class Orchestrator(OrchestratorInterface):
         )
         
         # Initialize message bus
-        if self.use_redis:
+        if self.use_redis and REDIS_AVAILABLE:
             # Use Redis-backed message bus
             redis_config = self.component_config.get('redis', {})
             self.message_bus = RedisMessageBus(
